# tcra

Tropical Cyclone Risk Analysis [tcra] is a Python package that allows for the development of scenario-based tropical cyclone risk analysis of buildings and Electrical Power Network (EPN). This tool performs scenario-hazard analysis based on historical or simulated cyclone tracks, fragility-based damage analysis, damage ratio analysis, loss estimation, recovery simulation of damaged structures, and social impact assessments on the community. It also enables decision-makers to make rehabilitation decisions and perform rehabilitation scenario analysis.

# Libraries
Pandas, Numpy, Matplotlib, Folium

## Installation

```bash
pip install tcra

